@@ -40,6 +40,14 @@ class Lomax(
     def mode(self) -> float:
         return 0.0
 
+    @property
+    def lower_bound(self) -> float:
+        return 0.0
+
+    @property
+    def upper_bound(self) -> float:
+        return self.isf().at(0.01)
+
     def __str__(self):
 
         return (
@@ -58,3 +66,7 @@ class Lomax(
             abs(self._alpha - other._alpha) < 1e-10 and
             abs(self._lambda - other._lambda) < 1e-10
         )
+
+    def __ne__(self, other: 'Lomax') -> bool:
+
+        return not self.__eq__(other)
