@@ -55,6 +55,14 @@ class Normal(
     def _reset_distribution(self):
         self._distribution: rv_continuous = norm(self._mu, self._sigma)
 
+    @property
+    def lower_bound(self) -> float:
+        return self.isf().at(0.99)
+
+    @property
+    def upper_bound(self) -> float:
+        return self.isf().at(0.01)
+
     @staticmethod
     def StandardNormal():
         return Normal(mu=0, sigma=1)
@@ -100,3 +108,7 @@ class Normal(
             abs(self._mu - other._mu) < 1e-10 and
             abs(self._sigma - other._sigma) < 1e-10
         )
+
+    def __ne__(self, other: 'Normal') -> bool:
+
+        return not self.__eq__(other)
