@@ -56,6 +56,14 @@ class BetaBinomial(
             self._n, self._alpha, self._beta
         )
 
+    @property
+    def lower_bound(self) -> int:
+        return 0
+
+    @property
+    def upper_bound(self) -> int:
+        return self._n
+
     def __str__(self):
         return f'BetaBinomial(' \
                f'n={self._n}, ' \
@@ -78,3 +86,12 @@ class BetaBinomial(
                 abs(self._alpha - other._alpha) < 1e-10 and
                 abs(self._beta - other._beta) < 1e-10
             )
+
+    def __ne__(
+            self, other: Union['BetaBinomial', int, float]
+    ) -> Union[bool, float]:
+
+        if type(other) in (int, float):
+            return 1 - self.pmf().at(other)
+        else:
+            return not self.__eq__(other)
