@@ -38,6 +38,14 @@ class Poisson(
 
         self._distribution: rv_discrete = poisson(self._lambda)
 
+    @property
+    def lower_bound(self) -> int:
+        return 1
+
+    @property
+    def upper_bound(self) -> int:
+        return int(self.isf().at(0.01))
+
     def mode(self) -> int:
 
         return int(self._lambda)
@@ -56,3 +64,12 @@ class Poisson(
             return self.pmf().at(other)
         else:
             return abs(self._lambda - other._lambda) < 1e-10
+
+    def __ne__(
+            self, other: Union['Poisson', int, float]
+    ) -> Union[bool, float]:
+
+        if type(other) in (int, float):
+            return 1 - self.pmf().at(other)
+        else:
+            return not self.__eq__(other)
